====================
django-user-payments
====================

.. image:: https://travis-ci.org/matthiask/django-user-payments.svg?branch=master
    :target: https://travis-ci.org/matthiask/django-user-payments

.. image:: https://readthedocs.org/projects/django-user-payments/badge/?version=latest
    :target: https://django-user-payments.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Links
=====

- `Documentation on readthedocs.io <https://django-user-payments.readthedocs.io/>`_
- `Code on Github <https://github.com/matthiask/django-user-payments>`_
- `Package on PyPI <https://pypi.org/project/django-user-payments/>`_
